@@ -1,21 +1,22 @@
 """RIS writer for commonmeta-py"""
-from ..utils import to_ris
-from ..base_utils import compact, wrap, presence, parse_attributes
-from ..doi_utils import doi_from_url
+
+from ..base_utils import compact, parse_attributes, presence, wrap
 from ..constants import CM_TO_RIS_TRANSLATIONS
+from ..doi_utils import doi_from_url
+from ..utils import to_ris
 
 
 def write_ris(metadata):
     """Write ris"""
     container = metadata.container or {}
-    ris = CM_TO_RIS_TRANSLATIONS.get(metadata.type, "GEN")
+    _type = CM_TO_RIS_TRANSLATIONS.get(metadata.type, "GEN")
     ris = compact(
         {
-            "TY": ris,
+            "TY": _type,
             "T1": parse_attributes(metadata.titles, content="title", first=True),
             "T2": container.get("title", None),
-            "AU": to_ris(metadata.creators),
-            "DO": doi_from_url(metadata.id) if metadata.id else None,
+            "AU": to_ris(metadata.contributors),
+            "DO": doi_from_url(metadata.id),
             "UR": metadata.url,
             "AB": parse_attributes(
                 metadata.descriptions, content="description", first=True
@@ -25,7 +26,9 @@ def write_ris(metadata):
                     wrap(metadata.subjects), content="subject", first=False
                 )
             ),
-            "PY": metadata.date.get('published')[:4] if metadata.date.get('published', None) else None,
+            "PY": metadata.date.get("published")[:4]
+            if metadata.date.get("published", None)
+            else None,
             "PB": metadata.publisher.get("name", None),
             "LA": metadata.language,
             "VL": container.get("volume", None),
@@ -40,9 +43,17 @@ def write_ris(metadata):
     )
     string = []
     for key, val in ris.items():
-        if isinstance(val, list):
+        if isinstance(val, list) and val not in [[], [None]]:
             for vai in val:
                 string.append(f"{key}  - {vai}")
-        else:
+        elif val not in [[], [None]]:
             string.append(f"{key}  - {val}")
     return "\r\n".join(string)
+
+
+def write_ris_list(metalist):
+    """Write RIS list"""
+    if metalist is None:
+        return None
+    items = [write_ris(item) for item in metalist.items]
+    return "\r\n\r\n".join(items)
